@@ -11,6 +11,8 @@
 
 #include <QCoreApplication>
 #include <QMimeDatabase>
+#include <QRegularExpression>
+#include <QStandardPaths>
 #include <QTextCodec>
 #include <QTextStream>
  
@@ -77,9 +79,7 @@ KQuery::KQuery(QObject *parent)
 
 KQuery::~KQuery()
 {
-    while (!m_regexps.isEmpty()) {
-        delete m_regexps.takeFirst();
-    }
+    qDeleteAll(m_regexps);
     m_fileItems.clear();
     if (processLocate->state() == QProcess::Running) {
         disconnect(processLocate);
@@ -108,7 +108,7 @@ void KQuery::start()
         m_url = m_url.adjusted(QUrl::NormalizePathSegments);
 
         processLocate->clearProgram();
-        processLocate->setProgram(QStringLiteral("locate"), QStringList() <<  m_url.toLocalFile());
+        processLocate->setProgram(QStandardPaths::findExecutable(QStringLiteral("locate")), QStringList{m_url.toLocalFile()});
 
         processLocate->setOutputChannelMode(KProcess::SeparateChannels);
         processLocate->start();
@@ -140,10 +140,8 @@ void KQuery::slotResult(KJob *_job)
 
 void KQuery::slotListEntries(KIO::Job *, const KIO::UDSEntryList &list)
 {
-    const KIO::UDSEntryList::ConstIterator end = list.constEnd();
-
-    for (KIO::UDSEntryList::ConstIterator it = list.constBegin(); it != end; ++it) {
-        m_fileItems.enqueue(KFileItem(*it, m_url, true, true));
+    for (const KIO::UDSEntry &entry : list) {
+        m_fileItems.enqueue(KFileItem(entry, m_url, true, true));
     }
 
     checkEntries();
@@ -198,12 +196,9 @@ void KQuery::slotListEntries(const QStringList &list)
     metaKeyRx = QRegExp(m_metainfokey);
     metaKeyRx.setPatternSyntax(QRegExp::Wildcard);
 
-    QStringList::const_iterator it = list.constBegin();
-    QStringList::const_iterator end = list.constEnd();
-
     m_foundFilesList.clear();
-    for (; it != end; ++it) {
-        processQuery(KFileItem(QUrl::fromLocalFile(*it)));
+    for (const auto &file : list) {
+        processQuery(KFileItem(QUrl::fromLocalFile(file)));
     }
 
     if (!m_foundFilesList.isEmpty()) {
@@ -224,10 +219,7 @@ void KQuery::processQuery(const KFileItem &file)
 
     bool matched = false;
 
-    QListIterator<QRegExp *> nextItem(m_regexps);
-    while (nextItem.hasNext())
-    {
-        QRegExp *reg = nextItem.next();
+    for (const QRegExp *reg : std::as_const(m_regexps)) {
         matched = matched || (reg == nullptr) || (reg->exactMatch(file.url().adjusted(QUrl::StripTrailingSlash).fileName()));
     }
     if (!matched) {
@@ -346,9 +338,8 @@ void KQuery::processQuery(const KFileItem &file)
                                                          KFileMetaData::ExtractionResult::ExtractMetaData);
             ex->extract(&result);
 
-            KFileMetaData::PropertyMap properties = result.properties();
-            KFileMetaData::PropertyMap::const_iterator it = properties.constBegin();
-            for (; it != properties.constEnd(); it++) {
+            const KFileMetaData::PropertyMultiMap properties = result.properties();
+            for (auto it = properties.cbegin(); it != properties.cend(); ++it) {
                 if (!metaKeyRx.exactMatch(KFileMetaData::PropertyInfo(it.key()).displayName())) {
                     continue;
                 }
@@ -382,10 +373,10 @@ void KQuery::processQuery(const KFileItem &file)
 
         // FIXME: doesn't work with non local files
 
+        const QRegularExpression xmlTags(QStringLiteral("<.*?>"));
         QString filename;
         QTextStream *stream = nullptr;
         QFile qf;
-        QRegExp xmlTags;
         QByteArray zippedXmlFileContent;
 
         // KWord's and OpenOffice.org's files are zipped...
@@ -408,10 +399,13 @@ void KQuery::processQuery(const KFileItem &file)
                 }
 
                 zippedXmlFileContent = zipfileEntry->data();
-                xmlTags.setPattern(QStringLiteral("<.*>"));
-                xmlTags.setMinimal(true);
                 stream = new QTextStream(zippedXmlFileContent, QIODevice::ReadOnly);
+
+                // QTextStream default encoding is UTF-8 in Qt6
+                #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 stream->setCodec("UTF-8");
+                #endif
+
                 isZippedOfficeDocument = true;
             } else {
                 qCWarning(KFING_LOG) << "Cannot open supposed ZIP file " << file.url();
@@ -440,7 +434,11 @@ void KQuery::processQuery(const KFileItem &file)
             qf.setFileName(filename);
             qf.open(QIODevice::ReadOnly);
             stream = new QTextStream(&qf);
+            #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            stream->setEncoding(QStringConverter::System);
+            #else
             stream->setCodec(QTextCodec::codecForLocale());
+            #endif
         }
 
         while (!stream->atEnd())
@@ -457,11 +455,11 @@ void KQuery::processQuery(const KFileItem &file)
                 str.remove(xmlTags);
             }
 
-	if (str.indexOf(m_context, 0, m_casesensitive ? Qt::CaseSensitive : Qt::CaseInsensitive) != -1) {
-	    matchingLine = QString::number(matchingLineNumber)+QStringLiteral(": ")+str.trimmed();
-	    found = true;
-	    break;
-	}
+            if (str.indexOf(m_context, 0, m_casesensitive ? Qt::CaseSensitive : Qt::CaseInsensitive) != -1) {
+                matchingLine = QString::number(matchingLineNumber) + QStringLiteral(": ") + str.trimmed();
+                found = true;
+                break;
+            }
             qApp->processEvents();
         }
 
@@ -529,19 +527,16 @@ void KQuery::setGroupname(const QString &groupname)
 
 void KQuery::setRegExp(const QString &regexp, bool caseSensitive)
 {
-    QRegExp *regExp = nullptr;
-    QRegExp sep(QStringLiteral(";"));
-    const QStringList strList = regexp.split(sep, Qt::SkipEmptyParts);
+    const QStringList strList = regexp.split(QLatin1Char(';'), Qt::SkipEmptyParts);
     //  QRegExp globChars ("[\\*\\?\\[\\]]", TRUE, FALSE);
-    while (!m_regexps.isEmpty()) {
-        delete m_regexps.takeFirst();
-    }
+    qDeleteAll(m_regexps);
+    m_regexps.clear();
+    m_regexps.reserve(strList.size());
 
     //  m_regexpsContainsGlobs.clear();
-    for (QStringList::ConstIterator it = strList.constBegin(); it != strList.constEnd(); ++it) {
-        regExp = new QRegExp((*it), (caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive), QRegExp::Wildcard);
+    for (const auto &str : strList) {
         //m_regexpsContainsGlobs.append(regExp->pattern().contains(globChars));
-        m_regexps.append(regExp);
+        m_regexps.append(new QRegExp(str, (caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive), QRegExp::Wildcard));
     }
 }
 
